#!/bin/ksh

# usage: copy-files.sh <installation dirextory>

if [ $# -lt 1 ]; then
  BASEDIR=$HOME/confman
else
  BASEDIR=$1
fi

DIR=`pwd`

BINFILES="confman regtest ctcpstarter netscape.sh"
AUDIOFILES="ring_conference.au"
LIBS="addressbook.jar confctrl.jar coreapi.jar confman-registry registry.jar rvs_roi.jar securityapi.jar sessdir.jar swingall.jar ui.jar"
DOCS="confman2.ps README DATE KNOWN_BUGS LICENSE"
ICONS="Titel.gif audio.big.sel.gif unknown.big.gif video.big.sel.gif arrow_down.gif audio.small.gif test.gif unknown.big.sel.gif video.small.gif arrow_up.gif blank-rev.gif text.big.gif unknown.gif whiteboard.big.gif broadcast.gif text.big.sel.gif unknown.small.gif whiteboard.big.sel.gif audio.big.gif conference.gif text.small.gif video.big.gif whiteboard.small.gif"

echo "Installing Confman 2.0 in $BASEDIR"

# create directories
echo "Creating directories"
DIRS="$BASEDIR/bin $BASEDIR/lib $BASEDIR/icons $BASEDIR/sounds $BASEDIR/doc"
if [ ! -d $BASEDIR ]; then
  mkdir -p $BASEDIR
fi
if [ ! $? -eq 0 ]; then
  exit 1
fi
for dir in $DIRS; do
  if [ ! -d $dir ]; then
    mkdir $dir
  fi
done

# copy bin-files
echo "copying files...\c"
cd $BASEDIR/bin
tar xf $DIR/confman.tar $BINFILES confman-linux.sh.tmpl build-registry.sh.tmpl

# copy libs
cd $BASEDIR/lib
tar xf $DIR/confman.tar $LIBS

# copy icons
cd $BASEDIR/icons
tar xf $DIR/confman.tar $ICONS

# copy audio files
cd $BASEDIR/sounds
tar xf $DIR/confman.tar $AUDIOFILES

# copy doc files
cd $BASEDIR/doc
for d in $DOCS; do
  cp $DIR/$d .
done

echo "Done."

# create start script
echo "creating confman.sh"
cd $BASEDIR/bin
cat confman-linux.sh.tmpl | sed s,PLEASE_SET_BASEDIR,$BASEDIR, > confman.sh
chmod +x $BASEDIR/bin/confman.sh
rm confman-linux.sh.tmpl
echo "creating build-registry.sh"
cat build-registry.sh.tmpl | sed s,PLEASE_SET_BASEDIR,$BASEDIR, > build-registry.sh
chmod +x $BASEDIR/bin/build-registry.sh
rm build-registry.sh.tmpl

# set up initial registry
echo "Setting up initial registry...\c"
./build-registry.sh
# set up icon path
./regtest '\RVS\Confman2\System\IconPath' "$BASEDIR/icons"
# set up audio path
./regtest '\RVS\Confman2\System\AudioPath' "$BASEDIR/sounds"
# make a copy of the registry
cp $HOME/confman/confman-registry $BASEDIR/lib
echo "Done."

# install jre
echo "Installing Java Runtime Environment..."
cd $BASEDIR
tar xvzf $DIR/rt_1.1.7-v1a-glibc-x86.tar.gz

# cleanup
echo "Cleaning up...\c"
cd ..
rm -rf data
echo "All done."
